/*
Coded by Mark Hicken (nekcih@yahoo.com)

This fix allows web pages to work both locally and remotely without errors.
It is especially useful when loading XML or other external data.  It will 
recursively set the document.domain property on all windows/framesets in 
the document.

NOTE: 
If you want this script to work on all child frames then you have to execute it 
after the window is done loading.

EXAMPLE USAGE:
In the head of your document add the following...

<script type="text/javascript" src="allowLocalAndRemoteAccess.js"></script>
<script type="text/javascript">
	function loadHandler() { allowLocalAndRemoteAccess('mydomain.com'); }
	if (window.attachEvent) { window.attachEvent('onload', loadHandler); }
	else if (window.addEventListener) { window.addEventListener('load', loadHandler, false); }
</script>

EXAMPLE USAGE 2:
In the case where you need to load an external XML file before your child 
framesets are done loading you can execute the code twice.

<script type="text/javascript" src="allowLocalAndRemoteAccess.js"></script>
<script type="text/javascript">
	// run it immediately for the top level window
	allowLocalAndRemoteAccess('mydomain.com', window.top, false); // not recursive
	
	// set up loadHandler to run it again for all child frames/windows
	function loadHandler() { allowLocalAndRemoteAccess('usaa.com'); }
	if (window.attachEvent) { window.attachEvent('onload', loadHandler); }
	else if (window.addEventListener) { window.addEventListener('load', loadHandler, false); }
</script>

*/

function allowLocalAndRemoteAccess(sDomain, oRootWindow, bRecurseFrames) {
	if(typeof(sDomain)=='undefined') { return; } // nothing to do without a domain
	if(typeof(oRootWindow)=='undefined') { oRootWindow = window.top; }
	if(typeof(bRecurseFrames)=='undefined') { bRecurseFrames = true; } // do all frames by default

	configFrame(oRootWindow, sDomain); // do top level window
	for(var fI=0; fI<oRootWindow.frames.length; fI++) {
		var oWin = oRootWindow.frames[fI];
		if(bRecurseFrames) { // do recursion on all frames
			allowLocalAndRemoteAccess(sDomain, oWin, bRecurseFrames); 
		}
	}
}
function configFrame(oWin, sDomain) {
	var sRequestType = oWin.location.toString().substring(0,5);
	if(sRequestType == 'http:') { // if it's a web request - http:
		try { document.domain = sDomain; }
		catch (e){ alert('Sorry, unable to set the domain.\r' + e.message); } 
	}
	else if(sRequestType == 'file:') { // else if it's a network/file request - file:
	}
}




// ---------------------------------------------------------------------------------------
// USAA specific code
// ---------------------------------------------------------------------------------------

// By default I'm going to run this once on the top window before it loads.
// Then I'll run it again for all child windows once it is done loading.
// This will allow xml to load in the top window before the rest of the frames
// get done loading.

// by default run it for USAA websites
allowLocalAndRemoteAccess('usaa.com', window.top, false);

// set up loadHandler to run it again for child frames
function loadHandler() { allowLocalAndRemoteAccess('usaa.com'); }
if (window.attachEvent) { window.attachEvent('onload', loadHandler); }
else if (window.addEventListener) { window.addEventListener('load', loadHandler, false); }
