/* ---------------------------------

written by Mark Hicken (nekcih@yahoo.com)

EXAMPLE USAGE:
<script type="text/javascript" src="quickKeys.js"></script>
<script>
	var fTrigFunction = function() { window.location = 'http://www.google.com/'; }
	quickKeys.addTrigger([17,71], fTrigFunction, true);

	var fTrigFunction2 = function() { window.location = 'http://www.msn.com/'; }
	quickKeys.addTrigger(["M","S","N"], fTrigFunction2, false);
</script>

----------------------------------- */




// ---------------------------------------
// set up quickKeys object
// ---------------------------------------

var quickKeys = new Object();
// setup arrays containing currently pressed down keys
quickKeys.aDownKeys = new Array();
quickKeys.aDownKeyCodes = new Array();
quickKeys.aTriggers = new Array();
quickKeys.addTrigger = function(aKeys, fTrigger, bUseNumericKeyCodes) {
	if(!bUseNumericKeyCodes) {
		for(var i=0; i<aKeys.length; i++) { // captialize all keys
			if(typeof(aKeys[i]) == "string") {
				aKeys[i] = aKeys[i].toUpperCase();
			}
		}
	}
	quickKeys.aTriggers[quickKeys.aTriggers.length] = [aKeys, fTrigger, bUseNumericKeyCodes];
}
quickKeys.clearTriggers = function() { quickKeys.aTriggers = new Array(); }
quickKeys.keyDown = function(e) {
	key = (e && e.which) ? e.which : event.keyCode ;
	sKey = String.fromCharCode(key).toUpperCase();

	quickKeys.aDownKeys.addArrayItem(sKey);
	quickKeys.aDownKeyCodes.addArrayItem(key);

	// check all triggers
	for(var i=0; i<quickKeys.aTriggers.length; i++) {
		var aTrigger = quickKeys.aTriggers[i]; // aKeys, fTrigger, bUseNumericKeyCodes

		var aTriggerKeys = aTrigger[0]; // aKeys
		var fTriggerFunction = aTrigger[1]; // fTrigger
		var aKeyArrayToCheck = (aTrigger[2]) ? quickKeys.aDownKeyCodes : quickKeys.aDownKeys ; // bUseNumericKeyCodes

		var bAllKeysAreDown = true;

		for(var j=0; j<aTriggerKeys.length; j++) {
			if(!aKeyArrayToCheck.isInArray(aTriggerKeys[j])) {
				bAllKeysAreDown = false;
				break;
			}
		}
		
		// if all keys were down then clear the arrays and execute the trigger function
		if(bAllKeysAreDown) {
			quickKeys.aDownKeys = new Array();
			quickKeys.aDownKeyCodes = new Array();
			fTriggerFunction(); // execute the trigger function
		}
	}
}
quickKeys.keyUp = function(e) {
	key = (e && e.which) ? e.which : event.keyCode ;
	sKey = String.fromCharCode(key);
	quickKeys.aDownKeys.delArrayItem(sKey);
	quickKeys.aDownKeyCodes.delArrayItem(key);
}

// ---------------------------------------
// activate quickKeys object
// ---------------------------------------

//capture key press differently depending on browser capabilities
if (navigator.appName == 'Netscape') {
	window.captureEvents(Event.KEYDOWN)
	window.captureEvents(Event.KEYUP)
}
document.onkeydown = quickKeys.keyDown;
document.onkeyup = quickKeys.keyUp;











// ------------- array functions -----------------

Array.prototype.addArrayItem = function(addItem) {
	if(!this.isInArray(addItem)) { 
		this[this.length] = addItem; 
	}
	return this;
}
Array.prototype.isInArray = function(arrayItem) {
	itemIsInArray = false;
	for(i=0; i<this.length; i++) {
		if(this[i]==arrayItem) { itemIsInArray=true; }
	}
	return itemIsInArray;
}
Array.prototype.delArrayItem = function(delItem) {
	for(i=0; i<this.length; i++) {
		if(this[i]==delItem) {
			//mark the item number for array reordering
			iKill=i;
			//move last array item to current location
			this[i]=this[this.length-1];
			//replace last array item with current item
			this[this.length-1]=delItem;
			//chop it off of the array
			this.length=this.length-1;
		}
	}
	if(typeof(iKill)!="undefined") {
		//put the array back to it's original order
		for(i=iKill; i<this.length; i++) {
			swap1=this[i];
			if(typeof(this[i+1])!="undefined") { 
				swap2=this[i+1]; 
				this[i]=swap2;
				this[i+1]=swap1;
			}
		}
	}
	return this;
}




